@@ -49,6 +49,10 @@
 #include <uhd_source_c.h>
 #endif
 
+#ifdef ENABLE_MIRI
+#include <miri_source_c.h>
+#endif
+
 #ifdef ENABLE_SDRPLAY
 #include <sdrplay_source_c.h>
 #endif
@@ -153,6 +157,10 @@ devices_t device::find(const device_t &hint)
   for (std::string dev : uhd_source_c::get_devices())
     devices.push_back( device_t(dev) );
 #endif
+#ifdef ENABLE_MIRI
+  for (std::string dev : miri_source_c::get_devices())
+    devices.push_back( device_t(dev) );
+#endif
 #ifdef ENABLE_SDRPLAY
   for (std::string dev : sdrplay_source_c::get_devices())
     devices.push_back( device_t(dev) );
