@@ -143,7 +143,7 @@ fcd_source_c::fcd_source_c(const std::string &args) :
 
   if ( FUNCUBE_V1 == _type )
   {
-    _src_v1 = gr::fcdproplus::fcd::make( dev_name );
+    _src_v1 = gr::funcube::fcd::make( dev_name );
     connect( _src_v1, 0, self(), 0 );
 
     set_gain( 20, "LNA" );
@@ -152,7 +152,7 @@ fcd_source_c::fcd_source_c(const std::string &args) :
 
   if ( FUNCUBE_V2 == _type )
   {
-    _src_v2 = gr::fcdproplus::fcdproplus::make( dev_name );
+    _src_v2 = gr::funcube::fcdpp::make( dev_name );
     connect( _src_v2, 0, self(), 0 );
 
     set_gain( 1, "LNA" );
@@ -237,10 +237,10 @@ osmosdr::freq_range_t fcd_source_c::get_freq_range( size_t chan )
 double fcd_source_c::set_center_freq( double freq, size_t chan )
 {
   if ( FUNCUBE_V1 == _type )
-    _src_v1->set_freq( float(freq) );
+    _src_v1->set_freq( freq );
 
   if ( FUNCUBE_V2 == _type )
-    _src_v2->set_freq( float(freq) );
+    _src_v2->set_freq( freq );
 
   _freq = freq;
 
